package com.flossom.system.service.impl;

import java.util.List;

import com.flossom.common.core.domain.entity.WxClockLog;
import com.flossom.common.core.mapper.WxClockLogMapper;
import com.flossom.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.flossom.system.service.IWxClockLogService;

/**
 * 用户打卡Service业务层处理
 *
 * @author flossom
 * @date 2024-02-21
 */
@Service
public class WxClockLogServiceImpl implements IWxClockLogService {

    @Autowired
    private WxClockLogMapper wxClockLogMapper;

    /**
     * 查询用户打卡
     *
     * @param id 用户打卡主键
     * @return 用户打卡
     */
    @Override
    public WxClockLog selectWxClockLogById(Long id) {
        return wxClockLogMapper.selectWxClockLogById(id);
    }

    /**
     * 查询用户打卡列表
     *
     * @param wxClockLog 用户打卡
     * @return 用户打卡
     */
    @Override
    public List<WxClockLog> selectWxClockLogList(WxClockLog wxClockLog) {
        return wxClockLogMapper.selectWxClockLogList(wxClockLog);
    }

    /**
     * 新增用户打卡
     *
     * @param wxClockLog 用户打卡
     * @return 结果
     */
    @Override
    public int insertWxClockLog(WxClockLog wxClockLog) {
        wxClockLog.setCreateTime(DateUtils.getNowDate());
        return wxClockLogMapper.insertWxClockLog(wxClockLog);
    }

    /**
     * 修改用户打卡
     *
     * @param wxClockLog 用户打卡
     * @return 结果
     */
    @Override
    public int updateWxClockLog(WxClockLog wxClockLog) {
        wxClockLog.setUpdateTime(DateUtils.getNowDate());
        return wxClockLogMapper.updateWxClockLog(wxClockLog);
    }

    /**
     * 批量删除用户打卡
     *
     * @param ids 需要删除的用户打卡主键
     * @return 结果
     */
    @Override
    public int deleteWxClockLogByIds(Long[] ids) {
        return wxClockLogMapper.deleteWxClockLogByIds(ids);
    }

    /**
     * 删除用户打卡信息
     *
     * @param id 用户打卡主键
     * @return 结果
     */
    @Override
    public int deleteWxClockLogById(Long id) {
        return wxClockLogMapper.deleteWxClockLogById(id);
    }
}
